.. openTEPES documentation master file, created by Andres Ramos

Research projects
=================
The model has being used in these research projects:

- `Open ENergy TRansition ANalyses for a low-carbon Economy (openENTRANCE) <https://openentrance.eu/>`_, developed for the **European Union**,
  aims at developing, using and disseminating an open, transparent and integrated modelling platform for assessing low-carbon transition pathways in Europe.
  `L. Olmos <https://www.iit.comillas.edu/people/olmos>`_, `S. Lumbreras <https://www.iit.comillas.edu/people/slumbreras>`_, `A. Ramos <https://www.iit.comillas.edu/people/aramos>`_,
  `E. Alvarez <https://www.iit.comillas.edu/people/ealvarezq>`_
  
.. image:: /../open-entrance_logo.png
   :scale: 40%
   :align: center

- `Analysis of the expansion and operation of the Spanish electricity system for a 2030-2050 time horizon <https://www.iit.comillas.edu/proyectos/mostrar_proyecto.php.en?nombre_abreviado=IBD_ANALISIS_H2030-50>`_, developed for **Iberdrola**,
  aims at evaluating the potential and role that each generation, storage and consumption technology can play in the future mix of the Spanish electricity system.
  `M. Rivier <https://www.iit.comillas.edu/people/michel>`_, `T. Gómez <https://www.iit.comillas.edu/people/tomas>`_, `A. Sánchez <https://www.iit.comillas.edu/people/alvaro>`_,
  `F. Martín <https://www.iit.comillas.edu/people/fmartin>`_, `J.P. Chaves <https://www.iit.comillas.edu/people/jchaves>`_, `T. Gerres <https://www.iit.comillas.edu/people/tgerres>`_, 
  `S. Huclin <https://www.iit.comillas.edu/people/shuclin>`_, `A. Ramos <https://www.iit.comillas.edu/people/aramos>`_

- `Assessment of the storage needs for the Spanish electric system in a horizon 2020-2050 with large share of renewables <https://www.iit.comillas.edu/proyectos/mostrar_proyecto.php.en?nombre_abreviado=IDAE_Almacenamiento>`_, developed for 
  the **Instituto para la Diversificación y Ahorro de la Energía (IDAE)**, aims at assessing, from a technical and economic point of view, the daily, weekly and seasonal storage needs for the Spanish electricity system in the 2020-2050 horizon.
  `A. Ramos <https://www.iit.comillas.edu/people/aramos>`_, `P. Linares <https://www.iit.comillas.edu/people/pedrol>`_, `J.P. Chaves <https://www.iit.comillas.edu/people/jchaves>`_,
  `J. García <https://www.iit.comillas.edu/people/javiergg>`_, `S. Wogrin <https://www.iit.comillas.edu/people/swogrin>`_, `J.J. Valentín <https://www.iit.comillas.edu/people/jjvalentin>`_
  
- `MODESC – Platform of innovative models for speeding the energy transition towards a decarbonized economy <https://www.iit.comillas.edu/proyectos/mostrar_proyecto.php.en?nombre_abreviado=MODESC_RETOS>`_, developed for the **Ministry of Science and Innovation**,
  aims at developing of a global platform that integrates innovative energy simulation and impact assessment models that allow speeding the decarbonization of the electricity system including the electrification of the energy demand. 
  `T. Gómez <https://www.iit.comillas.edu/people/tomas>`_, `M. Rivier <https://www.iit.comillas.edu/people/michel>`_, `J.P. Chaves <https://www.iit.comillas.edu/people/jchaves>`_,
  `A. Ramos <https://www.iit.comillas.edu/people/aramos>`_, `P. Linares <https://www.iit.comillas.edu/people/pedrol>`_, `F. Martín <https://www.iit.comillas.edu/people/fmartin>`_,
  `L. Herding <https://www.iit.comillas.edu/people/lherding>`_
  
- `Improving energy system modelling tools and capacity <https://www.iit.comillas.edu/proyectos/mostrar_proyecto.php.en?nombre_abreviado=REFORMS>`_, developed for the **European Commission**,
  aims at improving the description of the Spanish energy system in model TIMES-SINERGIA, from the technologies considered or a higher time resolution to the detailed modeling of the power sector, such as the inclusion of transmission constraints.
  `S. Lumbreras <https://www.iit.comillas.edu/people/slumbreras>`_, `A. Ramos <https://www.iit.comillas.edu/people/aramos>`_, `P. Linares <https://www.iit.comillas.edu/people/pedrol>`_,
  `J.C. Romero <https://www.iit.comillas.edu/people/jcromero>`_
  
- `European Climate and Energy Modelling Forum (ECEMF) <https://www.iit.comillas.edu/proyectos/mostrar_proyecto.php.en?nombre_abreviado=ECEMF>`_, developed for the **European Commission**,
  aims at improving the description of the Spanish energy system in model TIMES-SINERGIA, from the technologies considered or a higher time resolution to the detailed modeling of the power sector, such as the inclusion of transmission constraints.
  `S. Lumbreras <https://www.iit.comillas.edu/people/slumbreras>`_, `A. Ramos <https://www.iit.comillas.edu/people/aramos>`_, `L. Olmos <https://www.iit.comillas.edu/people/olmos>`_,
  `C. Mateo <https://www.iit.comillas.edu/people/cmateo>`_
